@@ -74,6 +74,8 @@ class ChessDaskCluster:
                 game_results.extend(ply_list)
             game_data = ChessDaskCluster.get_game_data(game_results, tasks_for_game["ply_count"])
             game_data["filename"] = str(game_no) + " " + game.headers["Event"]
+            if "game_id" in game.headers:
+                game_data["game_id"] = game.headers["game_id"]
         except TimeoutError:
             print("Game timed out: " + str(game_no))
         return game_data
@@ -149,4 +151,4 @@ class ChessDaskCluster:
         game_futures = self.client.map(ChessDaskCluster.analyse_game_in_worker, batch)
         for game_future in as_completed(game_futures):
             game_data = game_future.result()
-            handler(game_data)
+            handler(game_data)
\ No newline at end of file
